InsertOperation<T> class final

Inserts an item at a specific index.

Inheritance

Constructors

InsertOperation(int index, T item)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The index at which to insert the item.
final
item → T
The item to insert.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(List<T> list) List<T>
Apply this operation to a list and return the result.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited