onStore method
Called when a value is stored in the cache.
This happens after successful fetches and mutations.
Implementation
void onStore(String key) {}
Called when a value is stored in the cache.
This happens after successful fetches and mutations.
void onStore(String key) {}