InsertOperation<T> class
final
Inserts an item at a specific index.
- Inheritance
-
- Object
- ListOperation<
T> - InsertOperation
Constructors
- InsertOperation(int index, T item)
-
const
Properties
Methods
-
apply(
List< T> list) → List<T> -
Apply this operation to a list and return the result.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited