RemoveWhereOperation<T> class
final
Removes items from the list that match a predicate.
- Inheritance
-
- Object
- ListOperation<
T> - RemoveWhereOperation
Constructors
- RemoveWhereOperation(bool predicate(T))
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- item → T?
-
Returns
nullsince this operation removes items.no setteroverride - predicate → bool Function(T)
-
The predicate to match items for removal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
List< T> list) → List<T> -
Apply this operation to a list and return the result.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited